==> glf-api-1.1.RELEASE-sources.jar: org/seppiko/glf/event/BasicLoggerFactory.java <==
/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.glf.event;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import org.seppiko.glf.api.ILoggerFactory;
import org.seppiko.glf.api.Logger;

/**
 * Basic Logger Factory for default implementation
 *
 * @author Leonard Woo
 */
public class BasicLoggerFactory implements ILoggerFactory {

  final Map<String, DefaultLogger> loggers = new ConcurrentHashMap<>();

  @Override
  public Logger getLogger(String name) {
    DefaultLogger logger = loggers.get(name);
    if (logger == null) {
      logger = new DefaultLogger(name);
      loggers.put(name, logger);
    }
    return logger;
  }

  public List<String> getLoggerNames() {
    return new ArrayList<String>(loggers.keySet());
  }

  public List<DefaultLogger> getLoggers() {
    return new ArrayList<DefaultLogger>(loggers.values());
  }

  public void clear() {
    loggers.clear();
  }
}

==> glf-api-1.3.RELEASE-sources.jar: org/seppiko/glf/event/BasicLoggerFactory.java <==
/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.glf.event;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import org.seppiko.glf.api.ILoggerFactory;
import org.seppiko.glf.api.Logger;

/**
 * Basic Logger Factory for default implementation
 *
 * @author Leonard Woo
 */
public class BasicLoggerFactory implements ILoggerFactory {

  final Map<String, DefaultLogger> loggers = new ConcurrentHashMap<>();

  @Override
  public Logger getLogger(String name) {
    DefaultLogger logger = loggers.get(name);
    if (logger == null) {
      logger = new DefaultLogger(name);
      loggers.put(name, logger);
    }
    return logger;
  }

  public List<String> getLoggerNames() {
    return new ArrayList<>(loggers.keySet());
  }

  public List<DefaultLogger> getLoggers() {
    return new ArrayList<>(loggers.values());
  }

  public void clear() {
    loggers.clear();
  }
}
